==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridSortDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSortDescriptionsChangedEventArgsDescription } from "./GridSortDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSortDescriptionsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSortDescriptionsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSortDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
                GridSortDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSortDescriptionsChangedEventArgsDescriptionMetadata.c(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("SortDescriptions", "Collection:ColumnSortDescription:ColumnSortDescriptionCollection:ColumnSortDescription");
        }
        static d(a) {
            GridSortDescriptionsChangedEventArgsDescriptionMetadata.b(a);
            a.ac("GridSortDescriptionsChangedEventArgs", () => new GridSortDescriptionsChangedEventArgsDescription());
            a.ab("GridSortDescriptionsChangedEventArgs", GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSortDescriptionsChangedEventArgsDescriptionMetadata, 'GridSortDescriptionsChangedEventArgsDescriptionMetadata');
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridSortDescriptionsChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/GridSortDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSortDescriptionsChangedEventArgsDescription } from "./GridSortDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSortDescriptionsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSortDescriptionsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSortDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
                GridSortDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSortDescriptionsChangedEventArgsDescriptionMetadata.c(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("SortDescriptions", "Collection:ColumnSortDescription:ColumnSortDescriptionCollection:ColumnSortDescription");
        }
        static d(a) {
            GridSortDescriptionsChangedEventArgsDescriptionMetadata.b(a);
            a.ae("GridSortDescriptionsChangedEventArgs", () => new GridSortDescriptionsChangedEventArgsDescription());
            a.ad("GridSortDescriptionsChangedEventArgs", GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSortDescriptionsChangedEventArgsDescriptionMetadata, 'GridSortDescriptionsChangedEventArgsDescriptionMetadata');
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridSortDescriptionsChangedEventArgsDescriptionMetadata;
})();
